#
# spec file for package dhewm3
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dhewm3
Version:        1.5.4
Release:        1.3
Summary:        DOOM 3 source port
License:        GPL-3.0-only
URL:            https://dhewm3.org/
Source0:        https://github.com/dhewm/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  cmake(sdl2)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(openal)
Provides:       bundled(miniz)

%description
dhewm3 is a DOOM 3 GPL source port.
Unlike the original DOOM 3, dhewm3 uses:

- SDL for low level OS support, OpenGL and input handling
- OpenAL for audio output, all OS specific audio backends are gone
- OpenAL EFX for EAX reverb effects
- Better support for widescreen (and arbitrary display resolutions)

%prep
%setup -q
%autopatch -p1

%build
cd neo
%cmake -DREPRODUCIBLE_BUILD=ON ..
%make_jobs

%install
cd neo
%cmake_install

cd ..
install -Dpm 644 dist/linux/share/metainfo/org.dhewm3.Dhewm3.metainfo.xml %{buildroot}/%{_datadir}/metainfo/org.dhewm3.Dhewm3.metainfo.xml
install -Dpm 644 dist/linux/share/icons/hicolor/128x128/apps/org.dhewm3.Dhewm3.png %{buildroot}/%{_datadir}/icons/hicolor/128x128/apps/org.dhewm3.Dhewm3.png
install -Dpm 644 dist/linux/share/icons/hicolor/256x256/apps/org.dhewm3.Dhewm3.png %{buildroot}/%{_datadir}/icons/hicolor/256x256/apps/org.dhewm3.Dhewm3.png
install -Dpm 644 dist/linux/share/icons/hicolor/scalable/apps/org.dhewm3.Dhewm3.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/org.dhewm3.Dhewm3.svg
install -Dpm 644 dist/linux/share/applications/org.dhewm3.Dhewm3.desktop %{buildroot}%{_datadir}/applications/org.dhewm3.Dhewm3.desktop
install -Dpm 644 dist/linux/share/applications/org.dhewm3.Dhewm3.d3xp.desktop %{buildroot}%{_datadir}/applications/org.dhewm3.Dhewm3.d3xp.desktop

%check

%files
%doc README.md Changelog.md Configuration.md
%license COPYING.txt
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_datadir}/applications/org.dhewm3.Dhewm3.desktop
%{_datadir}/applications/org.dhewm3.Dhewm3.d3xp.desktop
%{_datadir}/icons/hicolor/*/apps/org.dhewm3.Dhewm3.*
%{_datadir}/metainfo/org.dhewm3.Dhewm3.metainfo.xml

%changelog
* Sat Aug  3 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.4
  * dhewm3-mods now contains game libs for several new mods:
  * Blood Mod v1.5
  * Perfected Doom3 (ROE) v7
  * Sikkmod v1.2 and Sikkmod RoE v1.1
  * A brand new settings menu that uses Dear ImGui.
  * "Soft" Particles (that don't "cut" into geometry but fade
    smoothly), based on code from The Dark Mod 2.04.
  * r_enableDepthCapture: Enable capturing depth buffer to texture,
    needed for the soft particles.
  * Replaced dependency on (external) zlib with integrated miniz.
  * HighDPI/Retina support.
  * Allow inverted mouse look (horizontally, vertically or both)
    with m_invertLook.
  * CVar to allow always run in single player (still drains
    stamina though!): in_allowAlwaysRunInSP.
  * VSync can be enabled/disabled on the fly, without restarting
    the renderer (still with r_swapInterval or in the menu, of
    course; needs SDL2).
  * Allow enabling/disabling HRTF with s_alHRTF.
  * s_alOutputLimiter: Configure OpenAL's output-limiter which
    temporarily reduces the overall volume when too many too loud
    sounds play at once, to avoid issues like clipping.
  * s_scaleDownAndClamp: Clamp and reduce volume of all sound to
    prevent clipping or temporary downscaling by OpenAL's output
    limiter.
  * If r_windowResizable is set, the dhewm3 window (when in
    windowed mode..) can be freely resized.
  * Fixed screenshots when using native Wayland
    (SDL_VIDEODRIVER=wayland).
  * If you enter the map command in the console, without any
    arguments, the current map name is printed.
  * Support OpenGL debug contexts and messages.
    (GL_ARB_debug_output). Can be enabled with r_glDebugContext 1.
  * Changing that CVar requires a vid_restart
    (or set it as startup argument).
- Remove Patch:
  * dhewm3-fix-desktop-files.patch (fixed upstream)
* Fri Mar 29 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.3
  * Support for gamepads. See Configuration.md for more information.
  * Support different file formats for screenshots by setting the
    r_screenshotFormat CVar (0 = TGA, still the default, 1 = BMP,
    2 = PNG, 3 = JPG). r_screenshotJpgQuality and
    r_screenshotPngCompression allow configuring how JPG/PNG are
    compressed.
  * Fixed problems with lights after loading a savegame.
  * Fix volume of some weapon sounds, like chaingun being too quit.
  * Fix MD3 model support
  * Several new CMake options:
    + To enable Clang/GCC Address Sanitizer and Undefined Behavior
    Sanitizer
    + Hardlink the game code into the executable (instead of using
    game DLLs, only supports base or d3xp then; needed for
    Undefined Behavior Sanitizer)
    + Force colored diagnostic output from GCC or Clang (esp.
    useful when building with ninja)
  * Fix several compiler warnings
  * Updated stb_image and stb_vorbis
  * Updated minizip (from zlib/contrib) to latest upstream code
  * Added in_namePressed CVar to print currently pressed key/button
    (useful for binding keys in the console or configs).
- Add patch
  * dhewm3-fix-desktop-files.patch
- Packages desktop files
- Adjust URL
* Wed Jun 15 2022 Mia Herkt <mia@0x0.st>
- Update to 1.5.2:
  * Gamma and Brightness are now applied in the shaders instead of
  by setting hardware gamma.  Can be disabled (so hardware gamma
  is used again) with `r_gammaInShaders 0`
  * Cycle through multiple Quicksave slots instead of immediately
  overwriting the last Quicksave. The `com_numQuicksaves` CVar
  allows setting the number of QuickSaves
  (gh#dhewm/dhewm3#392)
  * Make r_locksurfaces work
  It doesn't do exactly what its description and name suggests:
  it renders everything that is *currently* visible from the
  position/view the player had when setting `r_locksurfaces 1`.
  Originally it was supposed to render exactly the surfaces that
  * were* visible then, but I couldn't get that to work.
  This is pretty similar, but there may be differences with opened
  doors and such.
  (gh#dhewm/dhewm3#357)
  * Keyboard input improvements (mostly SDL2-only):
  - Support (hopefully) all keyboard keys on all kinds of keyboard
    layouts by using scancodes for otherwise unknown keys
  - Support typing in non-ASCII characters, if supported by Doom3
    (it supports ISO-8859-1)
  - Support the clipboard also on non-Windows platforms
    You can paste text from the clipboard into the console or
    other edit fields with `Shift+Insert`
  - Explicit support for Right Ctrl, Alt and Shift keys
    (can be bound to different actions than their left
    counterparts)
  - Added `in_grabKeyboard` CVar to make sure dhewm3 gets *all*
    keyboard input
    Prevents the Windows-key or Alt-Tab or whatever from taking
    focus from the game
  - Added `in_ignoreConsoleKey` - if set to `1`, the console is
    only opened with Shift+Esc, and the "console key" (that key
    between Esc, 1 and Tab) can be freely bound to an action
    (and its char can be typed in the console without closing
    it).
  - Added (SDL2-only) "auto" option for `in_kbd`: When not
    disabling the console key, dhewm3 will try to automatically
    detect it if `in_kbd` is set to "auto" (now default)
  * Reworked mouse-input and -grabbing code, using absolute mouse
  mode in fullscreen GUIs (except for the PDA, because it's
  implemented weirdly).
  This made releasing the mouse in the main menu possible, as now
  the ingame cursor is at the same position as the system cursor.
  * `s_alReverbGain` CVar to reduce EFX reverb effect intensity
  (gh#dhewm/dhewm3#365)
  * Pause (looped) sounds when entering menu
  (gh#dhewm/dhewm3#330)
  * Fixes for looped sounds
  (gh#dhewm/dhewm3#390)
  * Replace libjpeg with stb_image and libogg/libvorbis(file) with
  stb_vorbis
  - Now the only required external dependencies should be OpenAL,
    SDL, zlib and optionally libCURL (and of course the C and C++
    runtimes)
  * (Optionally) use libbacktrace on non-Windows platforms for more
  useful backtraces in case of crashes (usually linked statically)
  * Fixed endless loop (game locking up at startup) if graphics
  settings couldn't be applied
  (gh#dhewm/dhewm3#386)
  * Fixed some warnings and uninitialized variables
  * Work around dmap bug caused by GCC using FMA "optimizations"
  (gh#dhewm/dhewm3#147)
  * Prevent dhewm3 from being run as root on Unix-like systems to
  improve security
  * Replaced most usages of `strncpy()` with something safer to
  prevent buffer overflows (remaining cases should be safe).
  * Console output is now logged to `dhewm3log.txt`
  (last log is renamed to `dhewm3log-old.txt`)
  - On Windows it's in `My Documents/My Games/dhewm3/`
  - On Mac it's in `$HOME/Library/Application Support/dhewm3/`
  - On other Unix-like systems like Linux it's in
    `$XDG_DATA_HOME/dhewm3/` (usually `$HOME/.local/share/dhewm3/`)
  * Improved compatibility with Wayland
  (gh#dhewm/dhewm3#426)
  * Work around assertion in AlphaLabs4 due to "ride_of_death"
  yeeting the dead "monster_zsec_shotgun_12" into the void
  (gh#dhewm/dhewm3#409)
  * Support loading some mods known to need `fs_game_base d3xp` via
  Mods menu (currently, *The Lost Mission* and *LibreCoop d3xp*
  are supported)
  * Disable assertion in idSampleDecoderLocal::DecodeOGG() that
  triggered when starting a new Classic Doom3 game
  (gh#dhewm/dhewm3#461)
* Sun Mar 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to 1.5.1:
  * Update savegame format. Old savegames still work, but new
    savegames can't be loaded with older versions of dhewm3!
  * dhewm3 now supports the Doom3 Demo gamedata.
  * Create the game window on the display the cursor is currently
    on (when using more than one display).
  * Added r_fullscreenDesktop CVar to set if fullscreen mode should
    be "classic" or "Desktop" which means a borderless window at.
    desktop resolution.
  * Fullscreen modes that are not at the current desktop resolution
    should work better now.
  * Several sound-related bugfixes.
  * Restore "Carmack's Reverse" Z-Fail stencil shadows; use
    glStencilOpSeparate() if available.
  * New CVar g_hitEffect: If set to 0, the player camera damage
    effects (like double-vision and extreme tilt) when being hit
    are disabled.
  * Fix lingering messages in HUD after loading savegame.
  * Fixed clipping bug in delta1.
  * Improve compatibility with some custom scripts.
  * Registering multiplayer servers at id's master-server fixed,
    so they can be found in the multiplayer menu.
  * Support for reproducible builds by setting the CMake option
    REPRODUCIBLE_BUILD.
  * Proper handling of paths with dots in directory names.
  * In the Spanish translation all the Alpha Lab autosaves got
    the same name, now the autosave name is based on the mapename
    instead which is distinct.
- Remove patch
  * 0001-Remove-use-of-date-time-macros.patch (fixed by upstream)
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sat Feb 23 2019 Martin Herkt <9+suse@cirno.systems>
- Update to 1.5.0 (no changelog)
- Drop 0002-Lower-release-build-optimizations-to-O2.patch
* Tue Jul  3 2018 9+suse@cirno.systems
- Use %%license macro
- Add 0002-Lower-release-build-optimizations-to-O2.patch
  * Fixes some undefined behavior caused by higher optimization
    levels. Picked from git master.
* Wed Jun 28 2017 jengelh@inai.de
- Trim redundant mentions from summary and description.
* Sat Jun 24 2017 9@cirno.systems
- Initial commit, 1.4.1
  * Fixed some (kinda rare) crashes due to assertion errors,
    especially observed in the last boss fights of both doom3
    and the Resurrection of Evil Addon.
  * Improved compatibility with AZERTY keyboards
    (the row of keys with 1...9, 0 is now usable)
  * Fixed a crash (at least on FreeBSD) when loading
    Resurrection of Evil's last level
  * Video resolutions in menu now sorted, added 2880x1800
  * Support for up to 8 mouse buttons
